@@ -1,4 +1,4 @@
-from re import sub
+import re
 
 
 def replace_colons(text: str, strip: bool=False) -> str:
@@ -6,7 +6,7 @@ def replace_colons(text: str, strip: bool=False) -> str:
     Unknown emoji are left as is unless `strip` is set to `True`
 
     :param text: String of text to parse and replace
-    :param strip: Whether to strip unknown codes or to leave them as `:unkown:`
+    :param strip: Whether to strip unknown codes or to leave them as `:unknown:`
 
     >>> emoji_data_python.replace_colons('Hello world ! :wave::skin-tone-3: :earth_africa: :exclamation:')
     'Hello world ! 👋🏼 🌍 ❗'
@@ -27,6 +27,19 @@ def replace_colons(text: str, strip: bool=False) -> str:
 
         return res
 
-    return sub(r'\:[a-zA-Z0-9-_+]+\:(\:skin-tone-[2-6]\:)?', emoji_repl, text)
+    return re.sub(r'\:[a-zA-Z0-9-_+]+\:(\:skin-tone-[2-6]\:)?', emoji_repl, text)
 
 
+def get_emoji_regex():
+    """Returns a regex to match any emoji
+
+    >>> emoji_data_python.get_emoji_regex().findall('Hello world ! 👋🏼 🌍 ❗')
+    ['👋', '🏼', '🌍', '❗']
+    """
+    from emoji_data_python import emoji_data
+    # Sort emojis by length to make sure mulit-character emojis are
+    # matched first
+
+    emojis = sorted([emoji.char for emoji in emoji_data], key=len, reverse=True)
+    pattern = u'(' + u'|'.join(re.escape(u) for u in emojis) + u')'
+    return re.compile(pattern)
